@@ -1,5 +1,5 @@
 package Pod::Autopod; ## Generates pod documentation by analysing perl modules.
-$Pod::Autopod::VERSION = '1.211';
+$Pod::Autopod::VERSION = '1.212';
 use 5.006; #Pod::Abstract uses features of 5.6
 use FileHandle;
 use strict;
@@ -1605,11 +1605,10 @@ my $path;
   if (!-e $dir){
 
     my @path=split(/\//,$dir);
-
     foreach my $p (@path){
-      if (!-e $p){
-        mkdir $path.$p
-        #print $path.$p."\n";
+      if (!-e $path.$p){
+        mkdir $path.$p;
+#        print "CREATE: ".$path.$p."\n";
       }
       $path.=$p.'/';
     }
@@ -1619,6 +1618,7 @@ my $path;
 
 
 
+
 sub _extractPath{
 my $p=shift;
 
